@@ -3,12 +3,13 @@ Main interface for codeguru-reviewer service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codeguru_reviewer import (
+    from mypy_boto3_codeguru_reviewer import (
         Client,
         CodeGuruReviewerClient,
         ListRepositoryAssociationsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,10 +17,11 @@ Usage::
     session_client: CodeGuruReviewerClient = session.client("codeguru-reviewer")
 
     list_repository_associations_paginator: ListRepositoryAssociationsPaginator = client.get_paginator("list_repository_associations")
+    ```
 """
 from mypy_boto3_codeguru_reviewer.client import (
-    CodeGuruReviewerClient as Client,
     CodeGuruReviewerClient,
+    CodeGuruReviewerClient as Client,
 )
 from mypy_boto3_codeguru_reviewer.paginator import ListRepositoryAssociationsPaginator
 
